﻿/*
 * This file is part of Clay Tablet, a simple cuneiform tablet simulator for Android
 *
 * Copyright (C) 2025 Batuhan Erdogan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package com.mehrphilalethes.claytablet

import android.content.Intent
import android.os.Bundle
import android.widget.Button
import android.widget.ToggleButton
import androidx.activity.ComponentActivity
// import androidx.activity.viewModels
import com.mehrphilalethes.claytablet.R.id
import com.mehrphilalethes.claytablet.view.SettingsActivity
import com.mehrphilalethes.claytablet.view.TabletCanvasView
// import com.mehrphilalethes.claytablet.viewmodel.TabletViewModel

class MainActivity : ComponentActivity() {

    // private val tabletViewModel: TabletViewModel by viewModels()
    private lateinit var tabletCanvasView: TabletCanvasView
    private var currentDeviceRotation = 180f

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        tabletCanvasView = findViewById(id.tabletCanvasView)
        val undoButton = findViewById<Button>(id.undoButton)
        val redoButton = findViewById<Button>(id.redoButton)
        val eraserButton = findViewById<ToggleButton>(id.eraserButton)
        val clearButton = findViewById<Button>(id.clearButton)
        val snapButton = findViewById<ToggleButton>(id.snapButton)
        val scrollButton = findViewById<ToggleButton>(id.scrollButton)
        val settingsButton = findViewById<Button>(id.settingsButton)
        val rotateButton = findViewById<Button>(id.rotateButton)

        // TODO: Add ViewModel integration later when transliteration logic is ready

        undoButton.setOnClickListener { tabletCanvasView.undo() }
        redoButton.setOnClickListener { tabletCanvasView.redo() }

        eraserButton.setOnCheckedChangeListener { _, isChecked ->
            if (isChecked) {
                eraserButton.setBackgroundResource(R.drawable.erase_on)
                tabletCanvasView.eraserMode = true
            } else {
                eraserButton.setBackgroundResource(R.drawable.erase_off)
                tabletCanvasView.eraserMode = false
            }
        }

        snapButton.setOnCheckedChangeListener { _, isChecked ->
            if (isChecked) {
                snapButton.setBackgroundResource(R.drawable.snap_on)
                tabletCanvasView.snapMode = true
            } else {
                snapButton.setBackgroundResource(R.drawable.snap_off)
                tabletCanvasView.snapMode = false
            }
        }

        scrollButton.setOnCheckedChangeListener { _, isChecked ->
            if (isChecked) {
                scrollButton.setBackgroundResource(R.drawable.scroll_on)
                tabletCanvasView.scrollMode = true
            } else {
                scrollButton.setBackgroundResource(R.drawable.scroll_off)
                tabletCanvasView.scrollMode = false
            }
        }

        clearButton.setOnClickListener { tabletCanvasView.clearTablet() }

        settingsButton.setOnClickListener {
            startActivity(Intent(this, SettingsActivity::class.java))
        }

        rotateButton.setOnClickListener {
            var newDeviceRotation = currentDeviceRotation + 90f
                currentDeviceRotation = newDeviceRotation
                tabletCanvasView.setDeviceRotation(newDeviceRotation - 180)
                rotateUIButtons(180 - newDeviceRotation)
        }
    }

    override fun onResume() {
        super.onResume()
        tabletCanvasView = findViewById(id.tabletCanvasView)
        tabletCanvasView.loadPreferences(this)
    }

    private fun rotateUIButtons(angle: Float) {
        val undoButton = findViewById<Button>(id.undoButton)
        val redoButton = findViewById<Button>(id.redoButton)
        val eraserButton = findViewById<ToggleButton>(id.eraserButton)
        val clearButton = findViewById<Button>(id.clearButton)
        val snapButton = findViewById<ToggleButton>(id.snapButton)
        val settingsButton = findViewById<Button>(id.settingsButton)
        val rotateButton = findViewById<Button>(id.rotateButton)

        val buttons = listOf(undoButton, redoButton, eraserButton, clearButton, snapButton, settingsButton, rotateButton)
        buttons.forEach { button ->
            button.animate()
                .rotation(angle)
                .setDuration(300)
                .start()
        }
    }
}
