﻿/*
 * This file is part of Clay Tablet, a simple cuneiform tablet simulator for Android
 *
 * Copyright (C) 2025 Batuhan Erdogan
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package com.mehrphilalethes.claytablet.viewmodel

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import com.mehrphilalethes.claytablet.model.WedgeSymbol
import com.mehrphilalethes.claytablet.model.TransliterationEngine

class TabletViewModel : ViewModel() {

    private val _wedges = mutableListOf<WedgeSymbol>()
    private val transliterationEngine = TransliterationEngine()

    fun addWedge(wedge: WedgeSymbol) {
        _wedges.add(wedge)
    }

    fun getWedges(): List<WedgeSymbol> {
        return _wedges
    }

    fun transliterate(): String {
        // Initially returns placeholder transliteration
        return transliterationEngine.transliterate(_wedges)
    }

    fun clearWedges() {
        _wedges.clear()
    }
}


